0Pricing
CUDA Academy · 课时

一个指针,两端通用

了解 cudaMallocManaged 的工作方式

一个指针,两端通用 是 CoddyKit 上的免费 CUDA Academy 课时。 这是第 1 节课,共 4 节。 你可以在下方免费阅读本课时的完整内容 — 然后在浏览器中使用内置代码编辑器和全天候 AI 导师进行实践。 这是 CUDA Academy 学习路径的一部分,你的进度在网页和 CoddyKit 应用中同步。 CUDA Academy 课程共包含 4 节课。

本课时的部分内容尚未翻译,以英文显示。

The Two-Pointer Headache

So far you juggled two pointers: one for the host, one for the device. Unified Memory replaces that pain with a single pointer both sides can use. 🙂

Meet cudaMallocManaged

You allocate managed memory with cudaMallocManaged. It hands back one address that works in your CPU code and inside your kernels alike.

float *data;
cudaMallocManaged(&data, n * sizeof(float));

No More cudaMemcpy

The big win: you usually skip the manual copies. With managed memory the runtime moves data for you, so cudaMemcpy often disappears from your code.

Write on the Host

You can fill the buffer with ordinary CPU code right after allocating. The same pointer you got is a normal address your loops can touch.

for (int i = 0; i < n; i++)
    data[i] = i;

Read on the Device

Pass that exact pointer to your kernel and the GPU threads dereference it directly. One address serves both worlds with no translation step.

kernel<<<blocks, threads>>>(data, n);

Sync Before You Read Back

After a kernel writes managed data, call cudaDeviceSynchronize before the CPU reads it. That guarantees the GPU finished and results are visible.

kernel<<<b, t>>>(data, n);
cudaDeviceSynchronize();

Free It Like Any Buffer

Managed memory is still device memory, so you release it with cudaFree. There is no special managed-free call to remember.

cudaFree(data);

Less Boilerplate, Fewer Bugs

Because you delete the alloc-copy-launch-copy-free dance, your programs shrink. Fewer copies means fewer chances to mix up directions or sizes.

Great for Prototyping

Unified Memory is perfect when you want a kernel running fast. You prototype quickly, then optimize transfers later only where they actually matter.

It Is Not Free Magic

The data still has to travel across PCIe under the hood. Convenience is real, but performance can lag hand-tuned copies until you add hints later.

When to Reach for It

Choose managed memory for simpler code, deep pointer structures, or oversubscribing GPU memory. It shines when clarity matters more than raw peak speed.

Quick Check

Let us confirm how managed allocation differs from the classic flow.

Recap: One Pointer, Both Sides

You learned that cudaMallocManaged hands you one pointer for host and device, dropping most copies. Sync before reading, free with cudaFree. Nice work! 🎉

常见问题解答

「一个指针,两端通用」课时是免费的吗?

是的 — 「一个指针,两端通用」的完整文本可在网页上免费阅读。要进行交互式练习(内置代码编辑器和全天候 AI 导师)并解锁 CUDA Academy 课程的其余内容,请升级到 CoddyKit PRO。 CUDA Academy 课程共包含 4 节课。

「一个指针,两端通用」这节课中我会学到什么?

了解 cudaMallocManaged 的工作方式 你通过在浏览器中直接运行的动手代码来练习 CUDA Academy,全天候 AI 导师会在你学习这节课的过程中回答你的问题。

学习 CUDA Academy 需要有经验吗?

无需任何先前经验。CoddyKit 上的 CUDA Academy 课程适合初学者到高级学习者,你可以从这里开始或从头开始,按照自己的节奏学习。 这是第 1 节课,共 4 节。

「一个指针,两端通用」课时需要多长时间?

大多数 CoddyKit 课程大约需要 5–10 分钟。每节课都很精短且互动,所以你能稳步进步,并在网页和应用中从离开的地方继续。

我能在这节 CUDA Academy 课中编写并运行代码吗?

能。每节 CUDA Academy 课都包含内置代码编辑器,你可以在浏览器中直接编写并运行真实代码,并获得即时 AI 反馈 — 无需本地设置。

此课程中的所有课时

  1. 一个指针,两端通用
  2. 按需迁移页面
  3. 使用 cudaMemPrefetchAsync 预取
  4. 通过 cudaMemAdvise 提供提示
← 返回 CUDA Academy